@@ -105,7 +105,7 @@ extract_initials_from_text (const char *text)
 
   g_free (normalized);
 
-  return g_string_free (initials, FALSE);
+  return g_string_free_and_steal (initials);
 }
 
 static void
@@ -236,7 +236,7 @@ update_custom_image_snapshot (AdwAvatar *self)
     scaled_height = size;
     scaled_width = (float) width * scaled_height / (float) height;
   } else if (width < height) {
-    scaled_width = self->size;
+    scaled_width = size;
     scaled_height = (float) height * scaled_width / (float) width;
   } else {
     scaled_width = scaled_height = size;
@@ -459,6 +459,7 @@ adw_avatar_init (AdwAvatar *self)
   gtk_widget_set_parent (GTK_WIDGET (self->custom_image), self->gizmo);
 
   self->text = g_strdup ("");
+  self->size = -1;
 
   set_class_color (self);
   update_initials (self);
@@ -523,12 +524,9 @@ adw_avatar_set_icon_name (AdwAvatar  *self,
 {
   g_return_if_fail (ADW_IS_AVATAR (self));
 
-  if (g_strcmp0 (self->icon_name, icon_name) == 0)
+  if (!g_set_str (&self->icon_name, icon_name))
     return;
 
-  g_clear_pointer (&self->icon_name, g_free);
-  self->icon_name = g_strdup (icon_name);
-
   update_icon (self);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_ICON_NAME]);
@@ -567,12 +565,9 @@ adw_avatar_set_text (AdwAvatar  *self,
 {
   g_return_if_fail (ADW_IS_AVATAR (self));
 
-  if (g_strcmp0 (self->text, text) == 0)
+  if (!g_set_str (&self->text, text ? text : ""))
     return;
 
-  g_clear_pointer (&self->text, g_free);
-  self->text = g_strdup (text ? text : "");
-
   set_class_color (self);
 
   update_initials (self);
