@@ -50,11 +50,6 @@
  * `AdwSpinRow` has the same structure as [class@ActionRow], as well as the
  * `.spin` style class on the main node.
  *
- * ## Accessibility
- *
- * `AdwSpinRow` uses an internal `GtkSpinButton` with the
- * `GTK_ACCESSIBLE_ROLE_SPIN_BUTTON` role.
- *
  * Since: 1.4
  */
 
@@ -267,7 +262,7 @@ adw_spin_row_class_init (AdwSpinRowClass *klass)
   widget_class->grab_focus = adw_spin_row_grab_focus;
 
   /**
-   * AdwSpinRow:adjustment:
+   * AdwSpinRow:adjustment: (attributes org.gtk.Property.get=adw_spin_row_get_adjustment org.gtk.Property.set=adw_spin_row_set_adjustment)
    *
    * The adjustment that holds the value of the spin row.
    *
@@ -279,7 +274,7 @@ adw_spin_row_class_init (AdwSpinRowClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSpinRow:climb-rate:
+   * AdwSpinRow:climb-rate: (attributes org.gtk.Property.get=adw_spin_row_get_climb_rate org.gtk.Property.set=adw_spin_row_set_climb_rate)
    *
    * The acceleration rate when you hold down a button or key.
    *
@@ -291,7 +286,7 @@ adw_spin_row_class_init (AdwSpinRowClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSpinRow:digits:
+   * AdwSpinRow:digits: (attributes org.gtk.Property.get=adw_spin_row_get_digits org.gtk.Property.set=adw_spin_row_set_digits)
    *
    * The number of decimal places to display.
    *
@@ -303,7 +298,7 @@ adw_spin_row_class_init (AdwSpinRowClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSpinRow:numeric:
+   * AdwSpinRow:numeric: (attributes org.gtk.Property.get=adw_spin_row_get_numeric org.gtk.Property.set=adw_spin_row_set_numeric)
    *
    * Whether non-numeric characters should be ignored.
    *
@@ -315,7 +310,7 @@ adw_spin_row_class_init (AdwSpinRowClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSpinRow:snap-to-ticks:
+   * AdwSpinRow:snap-to-ticks: (attributes org.gtk.Property.get=adw_spin_row_get_snap_to_ticks org.gtk.Property.set=adw_spin_row_set_snap_to_ticks)
    *
    * Whether invalid values are snapped to the nearest step increment.
    *
@@ -327,7 +322,7 @@ adw_spin_row_class_init (AdwSpinRowClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSpinRow:update-policy:
+   * AdwSpinRow:update-policy: (attributes org.gtk.Property.get=adw_spin_row_get_update_policy org.gtk.Property.set=adw_spin_row_set_update_policy)
    *
    * The policy for updating the spin row.
    *
@@ -342,7 +337,7 @@ adw_spin_row_class_init (AdwSpinRowClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSpinRow:value:
+   * AdwSpinRow:value: (attributes org.gtk.Property.get=adw_spin_row_get_value org.gtk.Property.set=adw_spin_row_set_value)
    *
    * The current value.
    *
@@ -354,7 +349,7 @@ adw_spin_row_class_init (AdwSpinRowClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwSpinRow:wrap:
+   * AdwSpinRow:wrap: (attributes org.gtk.Property.get=adw_spin_row_get_wrap org.gtk.Property.set=adw_spin_row_set_wrap)
    *
    * Whether the spin row should wrap upon reaching its limits.
    *
@@ -457,7 +452,7 @@ adw_spin_row_class_init (AdwSpinRowClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, spin_button_wrapped_cb);
   gtk_widget_class_bind_template_callback (widget_class, spin_button_notify_value_cb);
 
-  gtk_widget_class_set_accessible_role (widget_class, GTK_ACCESSIBLE_ROLE_PRESENTATION);
+  gtk_widget_class_set_accessible_role (widget_class, GTK_ACCESSIBLE_ROLE_TEXT_BOX);
 }
 
 static void
@@ -555,10 +550,9 @@ adw_spin_row_new (GtkAdjustment *adjustment,
  * set to the minimum value and a page increment of 10 * @step is the default.
  * The precision of the spin row is equivalent to the precisions of @step.
  *
- * ::: note
- *     The way in which the precision is derived works best if @step is a power
- *     of ten. If the resulting precision is not suitable for your needs, use
- *     [method@SpinRow.set_digits] to correct it.
+ * Note that the way in which the precision is derived works best if @step is a
+ * power of ten. If the resulting precision is not suitable for your needs,
+ * use [method@SpinRow.set_digits] to correct it.
  *
  * Returns: the new `AdwSpinRow`
  *
@@ -628,7 +622,7 @@ adw_spin_row_configure (AdwSpinRow    *self,
 }
 
 /**
- * adw_spin_row_get_adjustment:
+ * adw_spin_row_get_adjustment: (attributes org.gtk.Method.get_property=adjustment)
  * @self: a spin row
  *
  * Gets the adjustment that holds the value for the spin row.
@@ -648,7 +642,7 @@ adw_spin_row_get_adjustment (AdwSpinRow *self)
 }
 
 /**
- * adw_spin_row_set_adjustment:
+ * adw_spin_row_set_adjustment: (attributes org.gtk.Method.set_property=adjustment)
  * @self: a spin row
  * @adjustment: (nullable): an adjustment
  *
@@ -672,7 +666,7 @@ adw_spin_row_set_adjustment (AdwSpinRow    *self,
 }
 
 /**
- * adw_spin_row_get_climb_rate:
+ * adw_spin_row_get_climb_rate: (attributes org.gtk.Method.get_property=climb-rate)
  * @self: a spin row
  *
  * Gets the acceleration rate when you hold down a button or key.
@@ -690,7 +684,7 @@ adw_spin_row_get_climb_rate (AdwSpinRow *self)
 }
 
 /**
- * adw_spin_row_set_climb_rate:
+ * adw_spin_row_set_climb_rate: (attributes org.gtk.Method.set_property=climb-rate)
  * @self: a spin row
  * @climb_rate: the acceleration rate when you hold down a button or key
  *
@@ -714,7 +708,7 @@ adw_spin_row_set_climb_rate (AdwSpinRow *self,
 }
 
 /**
- * adw_spin_row_get_digits:
+ * adw_spin_row_get_digits: (attributes org.gtk.Method.get_property=digits)
  * @self: a spin row
  *
  * Gets the number of decimal places to display.
@@ -732,7 +726,7 @@ adw_spin_row_get_digits (AdwSpinRow *self)
 }
 
 /**
- * adw_spin_row_set_digits:
+ * adw_spin_row_set_digits: (attributes org.gtk.Method.set_property=digits)
  * @self: a spin row
  * @digits: the number of decimal places to display
  *
@@ -755,7 +749,7 @@ adw_spin_row_set_digits (AdwSpinRow *self,
 }
 
 /**
- * adw_spin_row_get_numeric:
+ * adw_spin_row_get_numeric: (attributes org.gtk.Method.get_property=numeric)
  * @self: a spin row
  *
  * Gets whether non-numeric characters should be ignored.
@@ -773,7 +767,7 @@ adw_spin_row_get_numeric (AdwSpinRow *self)
 }
 
 /**
- * adw_spin_row_set_numeric:
+ * adw_spin_row_set_numeric: (attributes org.gtk.Method.set_property=numeric)
  * @self: a spin row
  * @numeric: whether non-numeric characters should be ignored
  *
@@ -798,7 +792,7 @@ adw_spin_row_set_numeric (AdwSpinRow *self,
 }
 
 /**
- * adw_spin_row_get_snap_to_ticks:
+ * adw_spin_row_get_snap_to_ticks: (attributes org.gtk.Method.get_property=snap-to-ticks)
  * @self: a spin row
  *
  * Gets whether invalid values are snapped to nearest step increment.
@@ -816,7 +810,7 @@ adw_spin_row_get_snap_to_ticks (AdwSpinRow *self)
 }
 
 /**
- * adw_spin_row_set_snap_to_ticks:
+ * adw_spin_row_set_snap_to_ticks: (attributes org.gtk.Method.set_property=snap-to-ticks)
  * @self: a spin row
  * @snap_to_ticks: whether invalid values are snapped to the nearest step increment
  *
@@ -841,7 +835,7 @@ adw_spin_row_set_snap_to_ticks (AdwSpinRow *self,
 }
 
 /**
- * adw_spin_row_get_update_policy:
+ * adw_spin_row_get_update_policy: (attributes org.gtk.Method.get_property=update-policy)
  * @self: a spin row
  *
  * Gets the policy for updating the spin row.
@@ -859,7 +853,7 @@ adw_spin_row_get_update_policy (AdwSpinRow *self)
 }
 
 /**
- * adw_spin_row_set_update_policy:
+ * adw_spin_row_set_update_policy: (attributes org.gtk.Method.set_property=update-policy)
  * @self: a spin row
  * @policy: the policy for updating the spin row
  *
@@ -884,7 +878,7 @@ adw_spin_row_set_update_policy (AdwSpinRow                *self,
 }
 
 /**
- * adw_spin_row_get_value:
+ * adw_spin_row_get_value: (attributes org.gtk.Method.get_property=value)
  * @self: a spin row
  *
  * Gets the current value.
@@ -902,7 +896,7 @@ adw_spin_row_get_value (AdwSpinRow *self)
 }
 
 /**
- * adw_spin_row_set_value:
+ * adw_spin_row_set_value: (attributes org.gtk.Method.set_property=value)
  * @self: a spin row
  * @value: a new value
  *
@@ -923,7 +917,7 @@ adw_spin_row_set_value (AdwSpinRow *self,
 }
 
 /**
- * adw_spin_row_get_wrap:
+ * adw_spin_row_get_wrap: (attributes org.gtk.Method.get_property=wrap)
  * @self: a spin row
  *
  * Gets whether the spin row should wrap upon reaching its limits.
@@ -941,7 +935,7 @@ adw_spin_row_get_wrap (AdwSpinRow *self)
 }
 
 /**
- * adw_spin_row_set_wrap:
+ * adw_spin_row_set_wrap: (attributes org.gtk.Method.set_property=wrap)
  * @self: a spin row
  * @wrap: whether the spin row should wrap upon reaching its limits
  *
